<?php
/* Customize Appearance Options */
function frida_customizeAppearance( $wp_customize ) {

	/* Custom Text Area Control in Customizer */
	class frida_customTextAreaControl extends WP_Customize_Control {

		public $type = 'textarea';

		public function render_content() { ?>
			<label>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<textarea rows="8" style="width: 100%; resize: none;" <?php esc_url( $this->link() ); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
			</label>
			<?php
		}

	}
	/* */

		/* Sanitizers */
		function frida_sanitize_file( $file, $setting ) {
	    $mimes = array(
	        'jpg|jpeg|jpe' => 'image/jpeg',
	        'gif'          => 'image/gif',
	        'png'          => 'image/png'
	    );
	    $file_ext = wp_check_filetype( $file, $mimes );
	    return ( $file_ext['ext'] ? $file : $setting->default );
	  }

		function frida_sanitize_let_html( $input ) {
			return force_balance_tags( wp_kses_post( $input ) );
		}

		function frida_sanitize_checkbox( $input ) {
			if ( $input == 1 ) {
				return 1;
			} else {
				return '';
			}
		}

		function frida_sanitize_choices( $input, $setting ) {
			global $wp_customize;
			$control = $wp_customize->get_control( $setting->id );
			if ( array_key_exists( $input, $control->choices ) ) {
				return $input;
			} else {
				return $setting->default;
			}
		}

		function frida_sanitize_integer( $input ) {
			if( is_numeric( $input ) ) {
				return intval( $input );
			}
		}
		/* */

		/* Allowed HTML */
		$frida_allowed_html = array(
				'a' => array(
					'href' => array(),
					'target' => array(),
			),
			'span' => array(
				'class' => array(),
			),
			'br' => array(),
			'em' => array(),
			'strong' => array(),
			'hr' => array(),
		);
		/* */

	// Sections
	$wp_customize->add_section( 'brnhmbx_sectionGeneral', array(
		'title' => esc_html__( '1. General Settings', 'frida' ),
		'priority' => 0,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionBackground', array(
		'title' => esc_html__( '2. Site Background', 'frida' ),
		'priority' => 5,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionColors', array(
		'title' => esc_html__( '3. Site Colors', 'frida' ),
		'priority' => 10,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionHeader', array(
		'title' => esc_html__( '4. Header', 'frida' ),
		'priority' => 15,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionSocial', array(
		'title' => esc_html__( '5. Social Accounts', 'frida' ),
		'description' => wp_kses( __( 'Write the entire URL addresses.<br>Leave blank if not preferred.', 'frida' ), $frida_allowed_html ),
		'priority' => 20,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionLayout', array(
		'title' => esc_html__( '6. Layout Options', 'frida' ),
		'priority' => 25,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionPostFormatStandard', array(
		'title' => esc_html__( '7. Post Format: Standard', 'frida' ),
		'priority' => 30,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionPostFormatGallery', array(
		'title' => esc_html__( '8. Post Format: Gallery', 'frida' ),
		'priority' => 35,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionPostFormatVideo', array(
		'title' => esc_html__( '9. Post Format: Video', 'frida' ),
		'priority' => 40,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionPostFormatAside', array(
		'title' => esc_html__( '10. Post Format: Aside', 'frida' ),
		'priority' => 45,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionPostFormatLink', array(
		'title' => esc_html__( '11. Post Format: Link', 'frida' ),
		'priority' => 50,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionShowHide', array(
		'title' => esc_html__( '12. Show/Hide Elements', 'frida' ),
		'priority' => 55,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionRPPC', array(
		'title' => esc_html__( '13. Related Posts & Post Comments', 'frida' ),
		'priority' => 60,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionFooter', array(
		'title' => esc_html__( '14. Footer', 'frida' ),
		'priority' => 65,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionTranslation', array(
		'title' => esc_html__( '15. Translation', 'frida' ),
		'priority' => 70,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionCSS', array(
		'title' => esc_html__( '16. Custom CSS', 'frida' ),
		'description' => esc_html__( 'Write your CSS code to override styles.', 'frida' ),
		'priority' => 75,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionGoogleMaps', array(
		'title' => esc_html__( '17. Google Maps', 'frida' ),
		'priority' => 80,
	) );

	$wp_customize->add_section( 'brnhmbx_sectionSlider', array(
		'title' => esc_html__( '18. Slider Settings', 'frida' ),
		'priority' => 85,
	) );

	// Settings
	$wp_customize->add_setting( 'brnhmbx_upload_Favicon', array( 'sanitize_callback' => 'frida_sanitize_file' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_Fonts', array( 'default' => 'source', 'sanitize_callback' => 'frida_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_Fonts_Secondary', array( 'default' => 'noto', 'sanitize_callback' => 'frida_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_imageWidth', array( 'default' => 1080, 'sanitize_callback' => 'frida_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_imageHeight', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Background', array( 'default' => '#ddd7c7', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_upload_Background', array( 'sanitize_callback' => 'frida_sanitize_file' ) );
	$wp_customize->add_setting( 'brnhmbx_centerBackground', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_repeatBackground', array( 'default' => 'no-repeat', 'sanitize_callback' => 'frida_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_text_Logo', array( 'default' => wp_title(), 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Logo', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_upload_Logo', array( 'sanitize_callback' => 'frida_sanitize_file' ) );
	$wp_customize->add_setting( 'brnhmbx_upload_LogoRetina', array( 'sanitize_callback' => 'frida_sanitize_file' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_Banner', array( 'default' => 'no-banner', 'sanitize_callback' => 'frida_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_topBarHeight', array( 'default' => 180, 'sanitize_callback' => 'frida_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_logoPaddingBottom', array( 'default' => 40, 'sanitize_callback' => 'frida_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_menuPaddingBottom', array( 'default' => 40, 'sanitize_callback' => 'frida_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_MenuPos', array( 'default' => 'center', 'sanitize_callback' => 'frida_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_stickyHeader', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_triggerSticky', array( 'default' => 150, 'sanitize_callback' => 'frida_sanitize_integer' ) );
	$wp_customize->add_setting( 'frida_slicknav_apl', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_useFAIcon', array( 'default' => 'fa-pagelines', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Site_Header', array( 'default' => '#555', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Site_SubHeader', array( 'default' => '#777', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Site_MenuLevel', array( 'default' => '#aad3d9', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Site_TextOverImage', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Site_Liner', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Site_Content', array( 'default' => '#444', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Site_Link', array( 'default' => '#000', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Site_LinkHover', array( 'default' => '#1c7791', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Site_InputBackground', array( 'default' => '#e9e9e9', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Site_InputText', array( 'default' => '#777', 'sanitize_callback' => 'sanitize_hex_color' ) );
	/* Social Accounts */
	$wp_customize->add_setting( 'brnhmbx_social_Facebook', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Twitter', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Instagram', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Pinterest', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Google', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Tumblr', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Flickr', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Digg', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_LinkedIn', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Vimeo', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_YouTube', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Behance', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Dribble', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_DeviantArt', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Github', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Bloglovin', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_Lastfm', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_SoundCloud', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	$wp_customize->add_setting( 'brnhmbx_social_VK', array( 'default' => 'http://', 'sanitize_callback' => 'esc_url_raw' ) );
	/* */
	/* Translation */
	$wp_customize->add_setting( 'brnhmbx_tra_Lang', array( 'default' => ( get_bloginfo( 'language' ) ), 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_404', array( 'default' => 'Page not found', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Nothing', array( 'default' => 'Nothing found', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_SearchResults', array( 'default' => 'Search Results', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Page', array( 'default' => 'Page', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Tag', array( 'default' => 'Tag', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Category', array( 'default' => 'Category', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Author', array( 'default' => 'Author', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Archives', array( 'default' => 'Archives', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_OlderPosts', array( 'default' => 'Older Posts', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_NewerPosts', array( 'default' => 'Newer Posts', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_NextPost', array( 'default' => 'Next Post', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_PrevPost', array( 'default' => 'Previous Post', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_By', array( 'default' => 'by', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_BackToTop', array( 'default' => 'Back to Top', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_TypeKeyword', array( 'default' => 'Type keyword to search', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_RelatedPosts', array( 'default' => 'Related Posts', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_ReadMore', array( 'default' => 'Read More', 'sanitize_callback' => 'sanitize_text_field' ) );
	// Post Comments
	$wp_customize->add_setting( 'brnhmbx_tra_NoComment', array( 'default' => 'No comments', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Comment', array( 'default' => 'Comment', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Comments', array( 'default' => 'Comments', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Name', array( 'default' => 'Name', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Email', array( 'default' => 'Email', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Website', array( 'default' => 'Website', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_MustBeLogged', array( 'default' => 'You must be logged in to post a comment', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_LoginToReply', array( 'default' => 'Log in to Reply', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Logged', array( 'default' => 'Logged in', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_LogOut', array( 'default' => 'Log out', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_LeaveReply', array( 'default' => 'Leave a Reply', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_CancelReply', array( 'default' => 'Cancel Reply', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_PostComment', array( 'default' => 'Post Comment', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_At', array( 'default' => 'at', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Reply', array( 'default' => 'Reply', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Edit', array( 'default' => 'Edit', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Awaiting', array( 'default' => 'Comment awaiting approval', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_tra_Cookie', array( 'default' => 'Save my name, email, and website in this browser for the next time I comment', 'sanitize_callback' => 'sanitize_text_field' ) );
	/* */
	$wp_customize->add_setting( 'brnhmbx_text_Footer', array( 'default' => '© 2019 Frida. All rights reserved.', 'sanitize_callback' => 'frida_sanitize_let_html' ) );
	$wp_customize->add_setting( 'brnhmbx_text_CSS', array( 'default' => '', 'sanitize_callback' => 'frida_sanitize_let_html' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_Layout', array( 'default' => '1col_sidebar', 'sanitize_callback' => 'frida_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_Layout_Archive', array( 'default' => '1col_sidebar', 'sanitize_callback' => 'frida_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_PageWidth', array( 'default' => '1080', 'sanitize_callback' => 'frida_sanitize_choices' ) );
	/* Recent Posts & Post Comments */
	$wp_customize->add_setting( 'brnhmbx_color_RPPC_Background', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_RPPC_Header', array( 'default' => '#555', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_RPPC_Liner', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_RPPC_Content', array( 'default' => '#444', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_RPPC_DPL', array( 'default' => '#777', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_RPPC_Link', array( 'default' => '#555', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_RPPC_InputBackground', array( 'default' => '#e9e9e9', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_RPPC_InputText', array( 'default' => '#777', 'sanitize_callback' => 'sanitize_hex_color' ) );
	/* */
	/* Post Formats */
	$wp_customize->add_setting( 'brnhmbx_sh_FeaImg_Single_Standard', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_FeaImg_Standard', array( 'default' => 'fea', 'sanitize_callback' => 'frida_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_FeaImg_Gallery', array( 'default' => 'gal', 'sanitize_callback' => 'frida_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_GalleryPos_Gallery', array( 'default' => 'content', 'sanitize_callback' => 'frida_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_FeaImg_Video', array( 'default' => 'gal', 'sanitize_callback' => 'frida_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Standard', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Standard_Archive', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Gallery', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Gallery_Archive', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Video', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_ignoreExcerpt_Video_Archive', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_Background', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_Border', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_borderWidth_Standard', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_Header', array( 'default' => '#555', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_Liner', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_Content', array( 'default' => '#444', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_DCB', array( 'default' => '#777', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_Social', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_LinkB', array( 'default' => '#1c7791', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_InputBackground', array( 'default' => '#e9e9e9', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Standard_InputText', array( 'default' => '#777', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_keep_Gallery', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Gallery_Background', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Gallery_Border', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_borderWidth_Gallery', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Gallery_Header', array( 'default' => '#555', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Gallery_Liner', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Gallery_Content', array( 'default' => '#444', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Gallery_DCB', array( 'default' => '#777', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Gallery_Social', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Gallery_LinkB', array( 'default' => '#1c7791', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Gallery_InputBackground', array( 'default' => '#e9e9e9', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Gallery_InputText', array( 'default' => '#777', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_keep_Video', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Video_Background', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Video_Border', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_borderWidth_Video', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Video_Header', array( 'default' => '#555', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Video_Liner', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Video_Content', array( 'default' => '#444', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Video_DCB', array( 'default' => '#777', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Video_Social', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Video_LinkB', array( 'default' => '#1c7791', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Video_InputBackground', array( 'default' => '#e9e9e9', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Video_InputText', array( 'default' => '#777', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_keep_Aside', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Aside_Background', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Aside_Border', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_borderWidth_Aside', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Aside_Content', array( 'default' => '#444', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Aside_DCB', array( 'default' => '#777', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Aside_Social', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Aside_LinkB', array( 'default' => '#1c7791', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Aside_InputBackground', array( 'default' => '#e9e9e9', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Aside_InputText', array( 'default' => '#777', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_keep_Link', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Link_Background', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Link_Border', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_borderWidth_Link', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Link_Header', array( 'default' => '#555', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Link_Liner', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Link_DCB', array( 'default' => '#777', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Link_Social', array( 'default' => '#CCC', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Link_LinkB', array( 'default' => '#1c7791', 'sanitize_callback' => 'sanitize_hex_color' ) );
	/* */
	/* Show/Hide */
	$wp_customize->add_setting( 'brnhmbx_sh_btnToTop', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SocialAccounts', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SidebarPost_Standard', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SidebarPost_Gallery', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SidebarPost_Video', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SidebarInnerPage', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );

	$wp_customize->add_setting( 'brnhmbx_sh_RelatedPosts', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_frida_opt_RPBase', array( 'default' => 'tag', 'sanitize_callback' => 'frida_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_PostComments', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_PageComments', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Date', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Author', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Excerpt', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_btnReadMore', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SocialBar', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_btnComments', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_TagBar', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_CategoryBar', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Liners', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );

	$wp_customize->add_setting( 'brnhmbx_sh_SidebarPadding', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Sidebar_Background', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_ZigZag', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_color_MenuLink', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_MenuLink_Hover', array( 'default' => '#29747f', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Menu_Background', array( 'default' => '#9bc2c8', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Footer_Background', array( 'default' => '#b9af94', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Footer_Content', array( 'default' => '#ddd7c7', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Footer_Link', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Footer_Link_Hover', array( 'default' => '#7a453d', 'sanitize_callback' => 'sanitize_hex_color' ) );

	$wp_customize->add_setting( 'brnhmbx_mapPage', array( 'sanitize_callback' => 'frida_returnMapPageID' ) );
	$wp_customize->add_setting( 'brnhmbx_coorN', array( 'default' => '49.0138', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_coorE', array( 'default' => '8.38624', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_rng_MapZoom', array( 'default' => 15, 'sanitize_callback' => 'frida_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_mapHeight', array( 'default' => 500, 'sanitize_callback' => 'frida_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_Map', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_enableMapKey', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_mapAPI', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );

	/* Slider */
	$wp_customize->add_setting( 'brnhmbx_sliderShortcode', array( 'default' => '', 'sanitize_callback' => 'sanitize_text_field' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_SliderHomeView', array( 'default' => 'home-all', 'sanitize_callback' => 'frida_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SliderArchive', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sh_SliderPost', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_opt_SliderPosition', array( 'default' => 'cover', 'sanitize_callback' => 'frida_sanitize_choices' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Sli_Header', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Sli_Caption', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Sli_BT', array( 'default' => '#FFF', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_color_Sli_Box', array( 'default' => '#699b89', 'sanitize_callback' => 'sanitize_hex_color' ) );
	$wp_customize->add_setting( 'brnhmbx_rng_Sli_Box', array( 'default' => 90, 'sanitize_callback' => 'frida_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_sliderWidth', array( 'default' => 1080, 'sanitize_callback' => 'frida_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_sliderHeight', array( 'default' => 500, 'sanitize_callback' => 'frida_sanitize_integer' ) );
	/* */

	/* Footer Widgets */
	$wp_customize->add_setting( 'brnhmbx_use3ColFooter', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	/* */

	/* Slider Mobile Settings */
	$wp_customize->add_setting( 'brnhmbx_sliderHideMobile', array( 'default' => 'always', 'sanitize_callback' => 'frida_sanitize_choices' ) );
	/* */

	/* Slider Extra Settings */
	$wp_customize->add_setting( 'brnhmbx_bxAuto_Main', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sliderPause', array( 'default' => 4000, 'sanitize_callback' => 'frida_sanitize_integer' ) );
	$wp_customize->add_setting( 'brnhmbx_sliderInfinite', array( 'default' => 1, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sliderRandom', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_sliderMode', array( 'default' => 'horizontal', 'sanitize_callback' => 'frida_sanitize_choices' ) );
	/* */

	/* Separated Sidebars */
	$wp_customize->add_setting( 'brnhmbx_ExtraSidebar_Archive', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_ExtraSidebar_Page', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	$wp_customize->add_setting( 'brnhmbx_ExtraSidebar_Post', array( 'default' => 0, 'sanitize_callback' => 'frida_sanitize_checkbox' ) );
	/* */

	// Controls
	$wp_customize->add_control( 'brnhmbx_imageWidth', array(
    'label' => esc_html__( '1.1. Featured Image Width', 'frida' ),
		'description' => wp_kses( __( 'Default value is "1080".<br>Write "0" to not to resize the images.<br>Works for only new added ones.', 'frida' ), $frida_allowed_html ),
    'section' => 'brnhmbx_sectionGeneral',
    'settings' => 'brnhmbx_imageWidth',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_imageHeight', array(
    'label' => esc_html__( '1.2. Featured Image Height', 'frida' ),
		'description' => wp_kses( __( 'Write "0" to not to crop the images.<br>Works for only new added ones.', 'frida' ), $frida_allowed_html ),
    'section' => 'brnhmbx_sectionGeneral',
    'settings' => 'brnhmbx_imageHeight',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'brnhmbx_upload_Favicon', array(
				'label' => '1.3. Favicon',
				'section' => 'brnhmbx_sectionGeneral',
				'settings' => 'brnhmbx_upload_Favicon'
			)
		)
	);

	$wp_customize->add_control( 'brnhmbx_opt_Fonts', array(
		'label' => esc_html__( '1.4. Primary Font', 'frida' ),
    'section' => 'brnhmbx_sectionGeneral',
    'settings' => 'brnhmbx_opt_Fonts',
		'type' => 'radio',
		'choices' => array(
			'source' => 'Source Serif',
			'roboto' => 'Roboto',
			'arimo' => 'Arimo',
			'josefin' => 'Josefin Sans',
			'yomogi' => 'Yomogi',
			'roboto_serif' => 'Roboto Serif'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_Fonts_Secondary', array(
		'label' => esc_html__( '1.5. Secondary Font', 'frida' ),
    'section' => 'brnhmbx_sectionGeneral',
		'settings' => 'brnhmbx_opt_Fonts_Secondary',
		'type' => 'radio',
		'choices' => array(
			'noto' => 'Noto Serif',
			'open' => 'Open Sans',
			'ubuntu' => 'Ubuntu'
		)
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Background', array(
        'label' => esc_html__( '2.1. Background Color', 'frida' ), 'section' => 'brnhmbx_sectionBackground', 'settings' => 'brnhmbx_color_Background'
	) ) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'brnhmbx_upload_Background', array(
				'label' => '2.2. Background Image',
				'section' => 'brnhmbx_sectionBackground',
				'settings' => 'brnhmbx_upload_Background'
			)
		)
	);

	$wp_customize->add_control( 'brnhmbx_centerBackground', array(
        'label' => esc_html__( 'Centered Background Image', 'frida' ),
        'section' => 'brnhmbx_sectionBackground',
        'settings' => 'brnhmbx_centerBackground',
				'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_repeatBackground', array(
    'label' => esc_html__( '2.3. Background Repeat Options', 'frida' ),
		'description' => esc_html__( 'Only used if "Centered" is unchecked.', 'frida' ),
    'section' => 'brnhmbx_sectionBackground',
    'settings' => 'brnhmbx_repeatBackground',
		'type' => 'radio',
		'choices' => array(
			'no-repeat' => 'No Repeat',
			'repeat-x' => 'Repeat Only Horizontally',
			'repeat-y' => 'Repeat Only Vertically',
		)
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Site_Header', array(
        'label' => esc_html__( 'Header Color', 'frida' ), 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_Site_Header'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Site_SubHeader', array(
        'label' => esc_html__( 'Secondary Header Color', 'frida' ), 'description' => esc_html__( 'Used for date etc.', 'frida' ), 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_Site_SubHeader'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Menu_Background', array(
        'label' => esc_html__( 'Menu Background Color', 'frida' ), 'section' => 'brnhmbx_sectionHeader', 'settings' => 'brnhmbx_color_Menu_Background'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Site_MenuLevel', array(
        'label' => esc_html__( 'Menu Level Background Color', 'frida' ), 'section' => 'brnhmbx_sectionHeader', 'settings' => 'brnhmbx_color_Site_MenuLevel'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_MenuLink', array(
        'label' => esc_html__( 'Menu Link Color', 'frida' ), 'section' => 'brnhmbx_sectionHeader', 'settings' => 'brnhmbx_color_MenuLink'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_MenuLink_Hover', array(
        'label' => esc_html__( 'Menu Link Hover Color', 'frida' ), 'description' => esc_html__( 'This color will be used for the thin bar above the menu too.', 'frida' ), 'section' => 'brnhmbx_sectionHeader', 'settings' => 'brnhmbx_color_MenuLink_Hover'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Site_TextOverImage', array(
        'label' => esc_html__( 'Text Over Image Color', 'frida' ), 'description' => esc_html__( 'Used for "Image Widget"s header color etc.', 'frida' ), 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_Site_TextOverImage'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Site_Liner', array(
        'label' => esc_html__( 'Liner Color', 'frida' ), 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_Site_Liner'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Site_Content', array(
        'label' => esc_html__( 'Content Color', 'frida' ), 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_Site_Content'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Site_Link', array(
        'label' => esc_html__( 'Link Color', 'frida' ), 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_Site_Link'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Site_LinkHover', array(
        'label' => esc_html__( 'Link Hover Color', 'frida' ), 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_Site_LinkHover'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Site_InputBackground', array(
        'label' => esc_html__( 'Input Background Color', 'frida' ), 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_Site_InputBackground'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Site_InputText', array(
        'label' => esc_html__( 'Input Text Color', 'frida' ), 'section' => 'brnhmbx_sectionColors', 'settings' => 'brnhmbx_color_Site_InputText'
	) ) );

	$wp_customize->add_control( 'brnhmbx_text_Logo', array(
    'label' => esc_html__( '4.1. Logo Text', 'frida' ),
		'description' => esc_html__( 'Leave blank if you want to use the "Site Title". If a logo/banner image is uploaded, this will never be shown.', 'frida' ),
    'section' => 'brnhmbx_sectionHeader',
    'settings' => 'brnhmbx_text_Logo',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Logo', array(
        'label' => esc_html__( '4.2 Logo Text Color', 'frida' ), 'section' => 'brnhmbx_sectionHeader', 'settings' => 'brnhmbx_color_Logo'
	) ) );

	$wp_customize->add_control( 'brnhmbx_useFAIcon', array(
    'label' => esc_html__( '4.3. Font Awesome Icon', 'frida' ),
		'description' => wp_kses( __( "Choose from <a href='http://fortawesome.github.io/Font-Awesome/cheatsheet/' target='_blank'>'Font Awesome Cheatsheet'</a>.<br>Leave blank if you don't want to use.<br>Only used with text logo.", 'frida' ), $frida_allowed_html ),
    'section' => 'brnhmbx_sectionHeader',
    'settings' => 'brnhmbx_useFAIcon',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'brnhmbx_upload_Logo', array(
				'label' => '4.4. Logo/Banner Image',
				'section' => 'brnhmbx_sectionHeader',
				'settings' => 'brnhmbx_upload_Logo'
			)
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'brnhmbx_upload_LogoRetina', array(
				'label' => '4.5. Logo/Banner Image (Retina)',
				'description' => esc_html__( 'Must be 2X bigger from the original.', 'frida' ),
				'section' => 'brnhmbx_sectionHeader',
				'settings' => 'brnhmbx_upload_LogoRetina'
			)
		)
	);

	$wp_customize->add_control( 'brnhmbx_opt_MenuPos', array(
    'label' => esc_html__( '4.6. Menu Position', 'frida' ),
    'section' => 'brnhmbx_sectionHeader',
    'settings' => 'brnhmbx_opt_MenuPos',
		'type' => 'radio',
		'choices' => array(
			'right' => 'Right',
			'right-full' => 'Right (Fullwidth)',
			'center' => 'Center'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_stickyHeader', array(
    'label' => esc_html__( 'Sticky Header', 'frida' ),
    'section' => 'brnhmbx_sectionHeader',
    'settings' => 'brnhmbx_stickyHeader',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_triggerSticky', array(
		'description' => esc_html__( 'Trigger sticky header when scroll position is higher than:', 'frida' ),
    'section' => 'brnhmbx_sectionHeader',
    'settings' => 'brnhmbx_triggerSticky',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

		$wp_customize->add_control( 'frida_slicknav_apl', array(
			'label' => 'Clickable Parent Menu Items in Mobile Menu',
			'section' => 'brnhmbx_sectionHeader',
			'settings' => 'frida_slicknav_apl',
			'type' => 'checkbox'
		) );

	$wp_customize->add_control( 'brnhmbx_opt_Banner', array(
    'label' => esc_html__( '4.7. Banner Options', 'frida' ),
		'description' => wp_kses( __( 'Only used if "Menu Position" is "Center".<br>These options make sense when you want to place a big image.', 'frida' ), $frida_allowed_html ),
    'section' => 'brnhmbx_sectionHeader',
    'settings' => 'brnhmbx_opt_Banner',
		'type' => 'radio',
		'choices' => array(
			'no-banner' => 'No Banner',
			'yes-banner' => 'Banner',
			'yes-banner-full' => 'Banner (Fullwidth)',
			'yes-banner-fixed' => 'Banner (With fixed image height)'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_topBarHeight', array(
    'label' => esc_html__( '4.8. Top Bar Height', 'frida' ),
		'description' => esc_html__( 'Note that everything in it will be centered vertically. Write "0" to attach the logo/banner to the top.', 'frida' ),
    'section' => 'brnhmbx_sectionHeader',
    'settings' => 'brnhmbx_topBarHeight',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_logoPaddingBottom', array(
    'label' => esc_html__( '4.9. Logo Bottom Padding', 'frida' ),
		'description' => esc_html__( 'Only used if "Menu Position" is "Center".', 'frida' ),
    'section' => 'brnhmbx_sectionHeader',
    'settings' => 'brnhmbx_logoPaddingBottom',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_menuPaddingBottom', array(
    'label' => esc_html__( '4.10. Menu Bottom Padding', 'frida' ),
		'description' => esc_html__( 'Only used if "Menu Position" is "Center".', 'frida' ),
    'section' => 'brnhmbx_sectionHeader',
    'settings' => 'brnhmbx_menuPaddingBottom',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	/* Social Accounts */
	$wp_customize->add_control( 'brnhmbx_sh_SocialAccounts', array(
        'label' => esc_html__( 'Show Social Account Icons', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_sh_SocialAccounts',
				'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Facebook', array(
        'label' => esc_html__( 'Facebook', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Facebook',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Twitter', array(
        'label' => esc_html__( 'Twitter', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Twitter',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Instagram', array(
        'label' => esc_html__( 'Instagram', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Instagram',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Pinterest', array(
        'label' => esc_html__( 'Pinterest', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Pinterest',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Google', array(
        'label' => esc_html__( 'Google+', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Google',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Tumblr', array(
        'label' => esc_html__( 'Tumblr', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Tumblr',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Flickr', array(
        'label' => esc_html__( 'Flickr', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Flickr',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Digg', array(
        'label' => esc_html__( 'Digg', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Digg',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_LinkedIn', array(
        'label' => esc_html__( 'LinkedIn', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_LinkedIn',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Vimeo', array(
        'label' => esc_html__( 'Vimeo', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Vimeo',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_YouTube', array(
        'label' => esc_html__( 'YouTube', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_YouTube',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Behance', array(
        'label' => esc_html__( 'Behance', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Behance',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Dribble', array(
        'label' => esc_html__( 'Dribbble', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Dribble',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_DeviantArt', array(
        'label' => esc_html__( 'DeviantArt', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_DeviantArt',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Github', array(
        'label' => esc_html__( 'Github', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Github',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Bloglovin', array(
        'label' => esc_html__( "Bloglovin'", 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Bloglovin',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_Lastfm', array(
        'label' => esc_html__( 'Last.fm', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_Lastfm',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_SoundCloud', array(
        'label' => esc_html__( 'SoundCloud', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_SoundCloud',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_social_VK', array(
        'label' => esc_html__( 'VK', 'frida' ),
        'section' => 'brnhmbx_sectionSocial',
        'settings' => 'brnhmbx_social_VK',
				'type' => 'text',
    ) );
	/* */

	/* Translation */
	$wp_customize->add_control( 'brnhmbx_tra_Lang', array(
        'label' => esc_html__( '15.1. Site Language', 'frida' ),
				'description' => esc_html__( 'Original: "', 'frida' ) . esc_html( get_bloginfo( 'language' ) ) . '"',
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Lang',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_404', array(
        'label' => esc_html__( '15.2. Wording', 'frida' ),
				'description' => esc_html__( 'Original: "Page not found"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_404',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Nothing', array(
				'description' => esc_html__( 'Original: "Nothing found"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Nothing',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_SearchResults', array(
				'description' => esc_html__( 'Original: "Search Results"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_SearchResults',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Page', array(
				'description' => esc_html__( 'Original: "Page"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Page',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Tag', array(
				'description' => esc_html__( 'Original: "Tag"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Tag',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Category', array(
				'description' => esc_html__( 'Original: "Category"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Category',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Author', array(
				'description' => esc_html__( 'Original: "Author"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Author',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Archives', array(
				'description' => esc_html__( 'Original: "Archives"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Archives',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_OlderPosts', array(
				'description' => esc_html__( 'Original: "Older Posts"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_OlderPosts',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_NewerPosts', array(
				'description' => esc_html__( 'Original: "Newer Posts"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_NewerPosts',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_NextPost', array(
				'description' => esc_html__( 'Original: "Next Post"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_NextPost',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_PrevPost', array(
				'description' => esc_html__( 'Original: "Previous Post"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_PrevPost',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_By', array(
				'description' => esc_html__( 'Original: "by"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_By',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_BackToTop', array(
				'description' => esc_html__( 'Original: "Back to Top"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_BackToTop',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_TypeKeyword', array(
				'description' => esc_html__( 'Original: "Type keyword to search"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_TypeKeyword',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_RelatedPosts', array(
				'description' => esc_html__( 'Original: "Related Posts"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_RelatedPosts',
				'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_ReadMore', array(
				'description' => esc_html__( 'Original: "Read More"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_ReadMore',
				'type' => 'text',
    ) );

	// Post Comments
	$wp_customize->add_control( 'brnhmbx_tra_NoComment', array(
        'label' => esc_html__( '5.3 Post Comments', 'frida' ),
		'description' => esc_html__( 'Original: "No Comments"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_NoComment',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Comment', array(
		'description' => esc_html__( 'Original: "Comment"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Comment',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Comments', array(
		'description' => esc_html__( 'Original: "Comments"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Comments',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Name', array(
		'description' => esc_html__( 'Original: "Name"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Name',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Email', array(
		'description' => esc_html__( 'Original: "Email"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Email',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Website', array(
		'description' => esc_html__( 'Original: "Website"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Website',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_MustBeLogged', array(
		'description' => esc_html__( 'Original: "You must be logged in to post a comment"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_MustBeLogged',
		'type' => 'text',
    ) );

		$wp_customize->add_control( 'brnhmbx_tra_LoginToReply', array(
			'description' => esc_html__( 'Original: "Log in to Reply"', 'frida' ),
	        'section' => 'brnhmbx_sectionTranslation',
	        'settings' => 'brnhmbx_tra_LoginToReply',
			'type' => 'text',
	    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Logged', array(
		'description' => esc_html__( 'Original: "Logged in"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Logged',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_LogOut', array(
		'description' => esc_html__( 'Original: "Log out"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_LogOut',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_LeaveReply', array(
		'description' => esc_html__( 'Original: "Leave a Reply"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_LeaveReply',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_CancelReply', array(
		'description' => esc_html__( 'Original: "Cancel Reply"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_CancelReply',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_PostComment', array(
		'description' => esc_html__( 'Original: "Post Comment"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_PostComment',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_At', array(
		'description' => esc_html__( 'Original: "at"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_At',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Reply', array(
		'description' => esc_html__( 'Original: "Reply"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Reply',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Edit', array(
		'description' => esc_html__( 'Original: "Edit"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Edit',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Awaiting', array(
		'description' => esc_html__( 'Original: "Comment awaiting approval"', 'frida' ),
        'section' => 'brnhmbx_sectionTranslation',
        'settings' => 'brnhmbx_tra_Awaiting',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_tra_Cookie', array(
			'description' => esc_html__( 'Original: "Save my name, email, and website in this browser for the next time I comment"', 'frida' ),
	        'section' => 'brnhmbx_sectionTranslation',
	        'settings' => 'brnhmbx_tra_Cookie',
			'type' => 'text',
	    ) );

	$wp_customize->add_control( 'brnhmbx_use3ColFooter', array(
        'label' => esc_html__( '3 Widget Columns', 'frida' ),
		'description' => esc_html__( 'Uncheck for 2 columns.', 'frida' ),
        'section' => 'brnhmbx_sectionFooter',
        'settings' => 'brnhmbx_use3ColFooter',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_text_Footer', array(
        'label' => esc_html__( '14.1. Copyright Text', 'frida' ),
        'section' => 'brnhmbx_sectionFooter',
        'settings' => 'brnhmbx_text_Footer',
		'type' => 'text',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Footer_Background', array(
        'label' => esc_html__( 'Footer Background Color', 'frida' ), 'section' => 'brnhmbx_sectionFooter', 'settings' => 'brnhmbx_color_Footer_Background'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Footer_Content', array(
        'label' => esc_html__( 'Footer Content Color', 'frida' ), 'section' => 'brnhmbx_sectionFooter', 'settings' => 'brnhmbx_color_Footer_Content'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Footer_Link', array(
        'label' => esc_html__( 'Footer Link Color', 'frida' ), 'section' => 'brnhmbx_sectionFooter', 'settings' => 'brnhmbx_color_Footer_Link'
	) ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Footer_Link_Hover', array(
        'label' => esc_html__( 'Footer Link Hover Color', 'frida' ), 'section' => 'brnhmbx_sectionFooter', 'settings' => 'brnhmbx_color_Footer_Link_Hover'
	) ) );

	$wp_customize->add_control( 'brnhmbx_opt_PageWidth', array(
		'label' => esc_html__( '6.1. Page Width Options', 'frida' ),
    'section' => 'brnhmbx_sectionLayout',
    'settings' => 'brnhmbx_opt_PageWidth',
		'type' => 'radio',
		'choices' => array(
			'1080' => '1080 px',
			'full' => 'Fullwidth'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_Layout', array(
		'label' => esc_html__( '6.2. Home Display Options', 'frida' ),
    'section' => 'brnhmbx_sectionLayout',
    'settings' => 'brnhmbx_opt_Layout',
		'type' => 'radio',
		'choices' => array(
			'1col' => '1 Column',
			'1col_sidebar' => '1 Column + Sidebar',
			'2col' => '2 Columns',
			'2col_sidebar' => '2 Columns + Sidebar',
			'3col' => '3 Columns'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_Layout_Archive', array(
		'label' => esc_html__( '6.3. Archive Display Options', 'frida' ),
    'section' => 'brnhmbx_sectionLayout',
    'settings' => 'brnhmbx_opt_Layout_Archive',
		'type' => 'radio',
		'choices' => array(
			'1col' => '1 Column',
			'1col_sidebar' => '1 Column + Sidebar',
			'2col' => '2 Columns',
			'2col_sidebar' => '2 Columns + Sidebar',
			'3col' => '3 Columns'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SidebarPadding', array(
        'label' => esc_html__( 'Sidebar Inner Left/Right Padding', 'frida' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_sh_SidebarPadding',
				'type' => 'checkbox',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Sidebar_Background', array(
        'label' => esc_html__( 'Sidebar Background Color', 'frida' ), 'section' => 'brnhmbx_sectionLayout', 'settings' => 'brnhmbx_color_Sidebar_Background'
	) ) );

	$wp_customize->add_control( 'brnhmbx_sh_ZigZag', array(
        'label' => esc_html__( 'Show Zig-Zag Effects', 'frida' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_ZigZag',
				'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SidebarPost_Standard', array(
		'label' => esc_html__( 'Show Sidebar on Standard Posts', 'frida' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_sh_SidebarPost_Standard',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SidebarPost_Gallery', array(
		'label' => esc_html__( 'Show Sidebar on Gallery Posts', 'frida' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_sh_SidebarPost_Gallery',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SidebarPost_Video', array(
		'label' => esc_html__( 'Show Sidebar on Video Posts', 'frida' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_sh_SidebarPost_Video',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SidebarInnerPage', array(
		'label' => esc_html__( 'Show Sidebar on Pages', 'frida' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_sh_SidebarInnerPage',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ExtraSidebar_Archive', array(
        'label' => esc_html__( 'Enable "Sidebar - Archive"', 'frida' ),
		'description' => esc_html__( 'Uncheck to use the default sidebar.', 'frida' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_ExtraSidebar_Archive',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_ExtraSidebar_Page', array(
        'label' => esc_html__( 'Enable "Sidebar - Page"', 'frida' ),
		'description' => esc_html__( 'Uncheck to use the default sidebar.', 'frida' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_ExtraSidebar_Page',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_ExtraSidebar_Post', array(
        'label' => esc_html__( 'Enable "Sidebar - Post"', 'frida' ),
		'description' => esc_html__( 'Uncheck to use the default sidebar.', 'frida' ),
        'section' => 'brnhmbx_sectionLayout',
        'settings' => 'brnhmbx_ExtraSidebar_Post',
		'type' => 'checkbox'
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_RelatedPosts', array(
		'label' => esc_html__( 'Show Related Posts', 'frida' ),
        'section' => 'brnhmbx_sectionRPPC',
        'settings' => 'brnhmbx_sh_RelatedPosts',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_frida_opt_RPBase', array(
		'label' => esc_html__( 'Related Term', 'frida' ),
        'section' => 'brnhmbx_sectionRPPC',
        'settings' => 'brnhmbx_frida_opt_RPBase',
		'type' => 'radio',
		'choices' => array(
			'tag' => 'Tag',
			'category' => 'Category'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_PostComments', array(
		'label' => esc_html__( 'Show Post Comments', 'frida' ),
        'section' => 'brnhmbx_sectionRPPC',
        'settings' => 'brnhmbx_sh_PostComments',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_PageComments', array(
		'label' => esc_html__( 'Show Page Comments', 'frida' ),
        'section' => 'brnhmbx_sectionRPPC',
        'settings' => 'brnhmbx_sh_PageComments',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_FeaImg_Single_Standard', array(
		'label' => esc_html__( 'Show Featured Image on Post Pages', 'frida' ),
        'section' => 'brnhmbx_sectionPostFormatStandard',
        'settings' => 'brnhmbx_sh_FeaImg_Single_Standard',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Standard', array(
		'label' => esc_html__( 'Show full post at Home Page', 'frida' ),
        'section' => 'brnhmbx_sectionPostFormatStandard',
        'settings' => 'brnhmbx_ignoreExcerpt_Standard',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Standard_Archive', array(
		'label' => esc_html__( 'Show full post on Archive Pages', 'frida' ),
        'section' => 'brnhmbx_sectionPostFormatStandard',
        'settings' => 'brnhmbx_ignoreExcerpt_Standard_Archive',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Gallery', array(
		'label' => esc_html__( 'Show full post at Home Page', 'frida' ),
        'section' => 'brnhmbx_sectionPostFormatGallery',
        'settings' => 'brnhmbx_ignoreExcerpt_Gallery',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Gallery_Archive', array(
		'label' => esc_html__( 'Show full post on Archive Pages', 'frida' ),
        'section' => 'brnhmbx_sectionPostFormatGallery',
        'settings' => 'brnhmbx_ignoreExcerpt_Gallery_Archive',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Video', array(
		'label' => esc_html__( 'Show full post at Home Page', 'frida' ),
        'section' => 'brnhmbx_sectionPostFormatVideo',
        'settings' => 'brnhmbx_ignoreExcerpt_Video',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_ignoreExcerpt_Video_Archive', array(
		'label' => esc_html__( 'Show full post on Archive Pages', 'frida' ),
        'section' => 'brnhmbx_sectionPostFormatVideo',
        'settings' => 'brnhmbx_ignoreExcerpt_Video_Archive',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Date', array(
		'label' => esc_html__( 'Show Date', 'frida' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_Date',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Author', array(
		'label' => esc_html__( 'Show Author', 'frida' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_Author',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Excerpt', array(
		'label' => esc_html__( 'Show Excerpt', 'frida' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_Excerpt',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_btnReadMore', array(
		'label' => esc_html__( 'Show Read More Button', 'frida' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_btnReadMore',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_SocialBar', array(
		'label' => esc_html__( 'Show Share Icons', 'frida' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_SocialBar',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_btnComments', array(
		'label' => esc_html__( 'Show Comments Icon', 'frida' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_btnComments',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_TagBar', array(
		'label' => esc_html__( 'Show Tag Info', 'frida' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_TagBar',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_CategoryBar', array(
		'label' => esc_html__( 'Show Category Info', 'frida' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_CategoryBar',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Liners', array(
		'label' => esc_html__( 'Show Liners within Headers', 'frida' ),
        'section' => 'brnhmbx_sectionShowHide',
        'settings' => 'brnhmbx_sh_Liners',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_FeaImg_Standard', array(
        'label' => esc_html__( '7.1. Featured Image Options', 'frida' ),
        'section' => 'brnhmbx_sectionPostFormatStandard',
        'settings' => 'brnhmbx_opt_FeaImg_Standard',
		'type' => 'radio',
		'choices' => array(
			'fea' => 'Show featured image',
			'no' => 'No image'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_FeaImg_Gallery', array(
        'label' => esc_html__( '8.1. Featured Image Options', 'frida' ),
        'section' => 'brnhmbx_sectionPostFormatGallery',
        'settings' => 'brnhmbx_opt_FeaImg_Gallery',
		'type' => 'radio',
		'choices' => array(
			'fea' => 'Show featured image',
			'gal' => 'Show gallery image(s)',
			'no' => 'No image'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_GalleryPos_Gallery', array(
        'label' => esc_html__( '8.2. Gallery Position', 'frida' ),
		'description' => esc_html__( 'Choose the gallery position on post page.', 'frida' ),
        'section' => 'brnhmbx_sectionPostFormatGallery',
        'settings' => 'brnhmbx_opt_GalleryPos_Gallery',
		'type' => 'radio',
		'choices' => array(
			'content' => 'Only in Content',
			'iof' => 'Instead of Featured Image',
			'both' => 'Both'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_opt_FeaImg_Video', array(
        'label' => esc_html__( '9.1. Featured Image Options', 'frida' ),
        'section' => 'brnhmbx_sectionPostFormatVideo',
        'settings' => 'brnhmbx_opt_FeaImg_Video',
		'type' => 'radio',
		'choices' => array(
			'fea' => 'Show featured image',
			'gal' => 'Show video(s)',
			'no' => 'No image'
		)
    ) );

	/* Related Posts & Post Comments */
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_RPPC_Background', array(
        'label' => esc_html__( 'Background Color', 'frida' ), 'section' => 'brnhmbx_sectionRPPC', 'settings' => 'brnhmbx_color_RPPC_Background'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_RPPC_Header', array(
        'label' => esc_html__( 'Header Color', 'frida' ), 'section' => 'brnhmbx_sectionRPPC', 'settings' => 'brnhmbx_color_RPPC_Header'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_RPPC_Liner', array(
        'label' => esc_html__( 'Liner Color', 'frida' ), 'section' => 'brnhmbx_sectionRPPC', 'settings' => 'brnhmbx_color_RPPC_Liner'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_RPPC_Content', array(
        'label' => esc_html__( 'Content Color', 'frida' ), 'section' => 'brnhmbx_sectionRPPC', 'settings' => 'brnhmbx_color_RPPC_Content'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_RPPC_DPL', array(
        'label' => esc_html__( 'Secondary Content Color', 'frida' ), 'description' => esc_html__( 'Used for date etc.', 'frida' ), 'section' => 'brnhmbx_sectionRPPC', 'settings' => 'brnhmbx_color_RPPC_DPL'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_RPPC_Link', array(
        'label' => esc_html__( 'Link Color', 'frida' ), 'section' => 'brnhmbx_sectionRPPC', 'settings' => 'brnhmbx_color_RPPC_Link'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_RPPC_InputBackground', array(
        'label' => esc_html__( 'Input Background Color', 'frida' ), 'section' => 'brnhmbx_sectionRPPC', 'settings' => 'brnhmbx_color_RPPC_InputBackground'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_RPPC_InputText', array(
        'label' => esc_html__( 'Input Text Color', 'frida' ), 'section' => 'brnhmbx_sectionRPPC', 'settings' => 'brnhmbx_color_RPPC_InputText'
	) ) );
	/* */

	/* Post Format Colors*/
	// Standard Post
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_Background', array(
        'label' => esc_html__( 'Background Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatStandard', 'settings' => 'brnhmbx_color_Standard_Background'
	) ) );
	$wp_customize->add_control( 'brnhmbx_borderWidth_Standard', array(
        'label' => esc_html__( 'Border Width', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatStandard', 'settings' => 'brnhmbx_borderWidth_Standard', 'type' => 'number', 'input_attrs' => array( 'style' => 'width: 50px;' )
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_Border', array(
        'label' => esc_html__( 'Border Color', 'frida' ), 'description' => esc_html__( 'Only used if "Border Width" is higher than "0".', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatStandard', 'settings' => 'brnhmbx_color_Standard_Border'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_Header', array(
        'label' => esc_html__( 'Header Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatStandard', 'settings' => 'brnhmbx_color_Standard_Header'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_Liner', array(
        'label' => esc_html__( 'Liner Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatStandard', 'settings' => 'brnhmbx_color_Standard_Liner'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_Content', array(
        'label' => esc_html__( 'Content Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatStandard', 'settings' => 'brnhmbx_color_Standard_Content'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_DCB', array(
        'label' => esc_html__( 'Secondary Content Color', 'frida' ), 'description' => esc_html__( 'Used for date etc.', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatStandard', 'settings' => 'brnhmbx_color_Standard_DCB'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_Social', array(
        'label' => esc_html__( 'Icon Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatStandard', 'settings' => 'brnhmbx_color_Standard_Social'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_LinkB', array(
        'label' => esc_html__( 'Link Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatStandard', 'settings' => 'brnhmbx_color_Standard_LinkB'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_InputBackground', array(
        'label' => esc_html__( 'Input Background Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatStandard', 'settings' => 'brnhmbx_color_Standard_InputBackground'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Standard_InputText', array(
        'label' => esc_html__( 'Input Text Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatStandard', 'settings' => 'brnhmbx_color_Standard_InputText'
	) ) );
	// Gallery Post
	$wp_customize->add_control( 'brnhmbx_keep_Gallery', array(
        'label' => esc_html__( 'Keep the settings below but use "Standard Post Format" colors.', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatGallery', 'settings' => 'brnhmbx_keep_Gallery', 'type' => 'checkbox'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Gallery_Background', array(
        'label' => esc_html__( 'Background Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatGallery', 'settings' => 'brnhmbx_color_Gallery_Background'
	) ) );
	$wp_customize->add_control( 'brnhmbx_borderWidth_Gallery', array(
        'label' => esc_html__( 'Border Width', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatGallery', 'settings' => 'brnhmbx_borderWidth_Gallery', 'type' => 'number', 'input_attrs' => array( 'style' => 'width: 50px;' )
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Gallery_Border', array(
        'label' => esc_html__( 'Border Color', 'frida' ), 'description' => esc_html__( 'Only used if "Border Width" is higher than "0".', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatGallery', 'settings' => 'brnhmbx_color_Gallery_Border'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Gallery_Header', array(
        'label' => esc_html__( 'Header Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatGallery', 'settings' => 'brnhmbx_color_Gallery_Header'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Gallery_Liner', array(
        'label' => esc_html__( 'Liner Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatGallery', 'settings' => 'brnhmbx_color_Gallery_Liner'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Gallery_Content', array(
        'label' => esc_html__( 'Content Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatGallery', 'settings' => 'brnhmbx_color_Gallery_Content'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Gallery_DCB', array(
        'label' => esc_html__( 'Secondary Content Color', 'frida' ), 'description' => esc_html__( 'Used for date etc.', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatGallery', 'settings' => 'brnhmbx_color_Gallery_DCB'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Gallery_Social', array(
        'label' => esc_html__( 'Icon Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatGallery', 'settings' => 'brnhmbx_color_Gallery_Social'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Gallery_LinkB', array(
        'label' => esc_html__( 'Link Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatGallery', 'settings' => 'brnhmbx_color_Gallery_LinkB'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Gallery_InputBackground', array(
        'label' => esc_html__( 'Input Background Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatGallery', 'settings' => 'brnhmbx_color_Gallery_InputBackground'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Gallery_InputText', array(
        'label' => esc_html__( 'Input Text Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatGallery', 'settings' => 'brnhmbx_color_Gallery_InputText'
	) ) );
	// Video Post
	$wp_customize->add_control( 'brnhmbx_keep_Video', array(
        'label' => esc_html__( 'Keep the settings below but use "Standard Post Format" colors.', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatVideo', 'settings' => 'brnhmbx_keep_Video', 'type' => 'checkbox'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Video_Background', array(
        'label' => esc_html__( 'Background Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatVideo', 'settings' => 'brnhmbx_color_Video_Background'
	) ) );
	$wp_customize->add_control( 'brnhmbx_borderWidth_Video', array(
        'label' => esc_html__( 'Border Width', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatVideo', 'settings' => 'brnhmbx_borderWidth_Video', 'type' => 'number', 'input_attrs' => array( 'style' => 'width: 50px;' )
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Video_Border', array(
        'label' => esc_html__( 'Border Color', 'frida' ), 'description' => esc_html__( 'Only used if "Border Width" is higher than "0".', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatVideo', 'settings' => 'brnhmbx_color_Video_Border'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Video_Header', array(
        'label' => esc_html__( 'Header Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatVideo', 'settings' => 'brnhmbx_color_Video_Header'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Video_Liner', array(
        'label' => esc_html__( 'Liner Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatVideo', 'settings' => 'brnhmbx_color_Video_Liner'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Video_Content', array(
        'label' => esc_html__( 'Content Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatVideo', 'settings' => 'brnhmbx_color_Video_Content'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Video_DCB', array(
        'label' => esc_html__( 'Secondary Content Color', 'frida' ), 'description' => esc_html__( 'Used for date etc.', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatVideo', 'settings' => 'brnhmbx_color_Video_DCB'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Video_Social', array(
        'label' => esc_html__( 'Icon Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatVideo', 'settings' => 'brnhmbx_color_Video_Social'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Video_LinkB', array(
        'label' => esc_html__( 'Link Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatVideo', 'settings' => 'brnhmbx_color_Video_LinkB'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Video_InputBackground', array(
        'label' => esc_html__( 'Input Background Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatVideo', 'settings' => 'brnhmbx_color_Video_InputBackground'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Video_InputText', array(
        'label' => esc_html__( 'Input Text Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatVideo', 'settings' => 'brnhmbx_color_Video_InputText'
	) ) );
	// Aside Post
	$wp_customize->add_control( 'brnhmbx_keep_Aside', array(
        'label' => esc_html__( 'Keep the settings below but use "Standard Post Format" colors.', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatAside', 'settings' => 'brnhmbx_keep_Aside', 'type' => 'checkbox'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Aside_Background', array(
        'label' => esc_html__( 'Background Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatAside', 'settings' => 'brnhmbx_color_Aside_Background'
	) ) );
	$wp_customize->add_control( 'brnhmbx_borderWidth_Aside', array(
        'label' => esc_html__( 'Border Width', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatAside', 'settings' => 'brnhmbx_borderWidth_Aside', 'type' => 'number', 'input_attrs' => array( 'style' => 'width: 50px;' )
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Aside_Border', array(
        'label' => esc_html__( 'Border Color', 'frida' ), 'description' => esc_html__( 'Only used if "Border Width" is higher than "0".', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatAside', 'settings' => 'brnhmbx_color_Aside_Border'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Aside_Content', array(
        'label' => esc_html__( 'Content Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatAside', 'settings' => 'brnhmbx_color_Aside_Content'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Aside_DCB', array(
        'label' => esc_html__( 'Secondary Content Color', 'frida' ), 'description' => esc_html__( 'Used for date etc.', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatAside', 'settings' => 'brnhmbx_color_Aside_DCB'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Aside_Social', array(
        'label' => esc_html__( 'Icon Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatAside', 'settings' => 'brnhmbx_color_Aside_Social'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Aside_LinkB', array(
        'label' => esc_html__( 'Link Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatAside', 'settings' => 'brnhmbx_color_Aside_LinkB'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Aside_InputBackground', array(
        'label' => esc_html__( 'Input Background Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatAside', 'settings' => 'brnhmbx_color_Aside_InputBackground'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Aside_InputText', array(
        'label' => esc_html__( 'Input Text Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatAside', 'settings' => 'brnhmbx_color_Aside_InputText'
	) ) );
	// Link Post
	$wp_customize->add_control( 'brnhmbx_keep_Link', array(
        'label' => esc_html__( 'Keep the settings below but use "Standard Post Format" colors.', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatLink', 'settings' => 'brnhmbx_keep_Link', 'type' => 'checkbox'
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Link_Background', array(
        'label' => esc_html__( 'Background Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatLink', 'settings' => 'brnhmbx_color_Link_Background'
	) ) );
	$wp_customize->add_control( 'brnhmbx_borderWidth_Link', array(
        'label' => esc_html__( 'Border Width', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatLink', 'settings' => 'brnhmbx_borderWidth_Link', 'type' => 'number', 'input_attrs' => array( 'style' => 'width: 50px;' )
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Link_Border', array(
        'label' => esc_html__( 'Border Color', 'frida' ), 'description' => esc_html__( 'Only used if "Border Width" is higher than "0".', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatLink', 'settings' => 'brnhmbx_color_Link_Border'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Link_Header', array(
        'label' => esc_html__( 'Header Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatLink', 'settings' => 'brnhmbx_color_Link_Header'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Link_Liner', array(
        'label' => esc_html__( 'Liner Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatLink', 'settings' => 'brnhmbx_color_Link_Liner'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Link_DCB', array(
        'label' => esc_html__( 'Secondary Content Color', 'frida' ), 'description' => esc_html__( 'Used for date etc.', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatLink', 'settings' => 'brnhmbx_color_Link_DCB'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Link_Social', array(
        'label' => esc_html__( 'Icon Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatLink', 'settings' => 'brnhmbx_color_Link_Social'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Link_LinkB', array(
        'label' => esc_html__( 'Link Color', 'frida' ), 'section' => 'brnhmbx_sectionPostFormatLink', 'settings' => 'brnhmbx_color_Link_LinkB'
	) ) );
	/* */

	$wp_customize->add_control( new frida_customTextAreaControl( $wp_customize, 'brnhmbx_text_CSS', array(
        'section' => 'brnhmbx_sectionCSS',
        'settings' => 'brnhmbx_text_CSS',
		'type' => 'text',
    ) ) );

	/* Google Maps */
	$wp_customize->add_control( 'brnhmbx_mapPage', array(
        'label' => esc_html__( 'Choose a Page', 'frida' ),
        'section' => 'brnhmbx_sectionGoogleMaps',
        'settings' => 'brnhmbx_mapPage',
		 'type' => 'dropdown-pages',
    ) );

	$wp_customize->add_control( 'brnhmbx_coorN', array(
        'label' => esc_html__( 'Coordinate N', 'frida' ),
        'section' => 'brnhmbx_sectionGoogleMaps',
        'settings' => 'brnhmbx_coorN',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_coorE', array(
        'label' => esc_html__( 'Coordinate E', 'frida' ),
        'section' => 'brnhmbx_sectionGoogleMaps',
        'settings' => 'brnhmbx_coorE',
		'type' => 'text',
    ) );

	$wp_customize->add_control( 'brnhmbx_rng_MapZoom', array(
		'type'        => 'range',
		'section'     => 'brnhmbx_sectionGoogleMaps',
		'label'       => 'Zoom Level',
		'input_attrs' => array(
			'min'   => 5,
			'max'   => 19,
			'step'  => 1
		)
	) );

	$wp_customize->add_control( 'brnhmbx_mapHeight', array(
        'label' => esc_html__( 'Map Height', 'frida' ),
        'section' => 'brnhmbx_sectionGoogleMaps',
        'settings' => 'brnhmbx_mapHeight',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_sh_Map', array(
        'label' => esc_html__( 'Show Map', 'frida' ),
        'section' => 'brnhmbx_sectionGoogleMaps',
        'settings' => 'brnhmbx_sh_Map',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_enableMapKey', array(
		'label' => esc_html__( 'Enable Map API Key', 'frida' ),
		'section' => 'brnhmbx_sectionGoogleMaps',
		'settings' => 'brnhmbx_enableMapKey',
		'type' => 'checkbox',
	) );
	$wp_customize->add_control( 'brnhmbx_mapAPI', array(
		'label' => esc_html__( 'API Key', 'frida' ),
		'description' => esc_html__( 'Only used if "Enable Map API Key" is checked.', 'frida' ),
		'section' => 'brnhmbx_sectionGoogleMaps',
		'settings' => 'brnhmbx_mapAPI',
		'type' => 'text',
	) );

	function frida_returnMapPageID( $input ) {

		if( is_numeric( $input ) ) {

			return intval( $input );

		}

	}
	/* */

	/* Slider Colors & Settings */
	$wp_customize->add_control( 'brnhmbx_sliderShortcode', array(
        'label' => esc_html__( '18.1. Shortcode', 'frida' ),
		'description' => wp_kses( __( 'Example usage:<br>[fridaslider location="your_location"]', 'frida' ), $frida_allowed_html ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderShortcode',
		'type' => 'text',
		'input_attrs' => array(
			'style' => 'margin-bottom: 20px;',
		),
    ) );
	$wp_customize->add_control( 'brnhmbx_opt_SliderHomeView', array(
        'label' => esc_html__( '18.2. Home View Options', 'frida' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_opt_SliderHomeView',
		'type' => 'radio',
		'choices' => array(
			'home-all' => 'During Pagination',
			'home-front' => 'Only on the First Page of Pagination',
			'home-hide' => 'Hide at Home'
		)
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_SliderArchive', array(
        'label' => esc_html__( 'Show Slider on Archive Pages', 'frida' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sh_SliderArchive',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_sh_SliderPost', array(
        'label' => esc_html__( 'Show Slider on Post Pages', 'frida' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sh_SliderPost',
		'type' => 'checkbox'
    ) );
	$wp_customize->add_control( 'brnhmbx_opt_SliderPosition', array(
        'label' => esc_html__( '18.3. Position & Style', 'frida' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_opt_SliderPosition',
		'type' => 'radio',
		'choices' => array(
			'full' => 'Fullwidth',
			'cover' => 'Cover',
			'among' => 'Among the Posts'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_bxAuto_Main', array(
		'label' => esc_html__( 'Autoplay Slides', 'frida' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_bxAuto_Main',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sliderPause', array(
        'label' => esc_html__( 'Autoplay Duration', 'frida' ),
		'description' => wp_kses( __( 'Default value is "4000".<br>Only used if "Autoplay Slides" is checked.', 'frida' ), $frida_allowed_html ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderPause',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_sliderWidth', array(
        'label' => esc_html__( '18.4. Slide Image Width', 'frida' ),
		'description' => wp_kses( __( 'Default value is "1080".<br>Since the slider is responsive, display results may seem different. If you want to use "Fullwidth" option for instance, to set it 2560 and upload big images make sense.<br>Works for only new added images.', 'frida' ), $frida_allowed_html ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderWidth',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_sliderHeight', array(
        'label' => esc_html__( '18.5. Slide Image Height', 'frida' ),
		'description' => wp_kses( __( 'Default value is "500".<br>This value is fixed, not responsive.<br>Works for only new added images.', 'frida' ), $frida_allowed_html ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderHeight',
		'type' => 'number',
		'input_attrs' => array(
			'style' => 'width: 80px; margin-bottom: 20px;',
		),
    ) );

	$wp_customize->add_control( 'brnhmbx_sliderHideMobile', array(
		'label' => esc_html__( '18.6. Mobile Settings', 'frida' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderHideMobile',
		'type' => 'radio',
		'choices' => array(
			'always' => 'Always Show',
			'320' => 'Hide at 320px',
			'480' => 'Hide at 480px',
			'640' => 'Hide at 640px'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_sliderMode', array(
		'label' => esc_html__( '18.7. Transition Effect', 'frida' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderMode',
		'type' => 'radio',
		'choices' => array(
			'horizontal' => 'Horizontal',
			'fade' => 'Fade'
		)
    ) );

	$wp_customize->add_control( 'brnhmbx_sliderInfinite', array(
		'label' => esc_html__( 'Infinite Loop', 'frida' ),
		'description' => esc_html__( 'If checked, clicking "Next" while on the last slide will transition to the first slide and vice-versa.', 'frida' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderInfinite',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( 'brnhmbx_sliderRandom', array(
		'label' => esc_html__( 'Start with a Random Slide', 'frida' ),
        'section' => 'brnhmbx_sectionSlider',
        'settings' => 'brnhmbx_sliderRandom',
		'type' => 'checkbox',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Sli_Header', array(
        'label' => esc_html__( 'Slider Header Color', 'frida' ), 'section' => 'brnhmbx_sectionSlider', 'settings' => 'brnhmbx_color_Sli_Header'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Sli_Caption', array(
        'label' => esc_html__( 'Slider Caption Color', 'frida' ), 'section' => 'brnhmbx_sectionSlider', 'settings' => 'brnhmbx_color_Sli_Caption'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Sli_BT', array(
        'label' => esc_html__( 'Slider Button Color', 'frida' ), 'section' => 'brnhmbx_sectionSlider', 'settings' => 'brnhmbx_color_Sli_BT'
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'brnhmbx_color_Sli_Box', array(
        'label' => esc_html__( 'Slider Box Color', 'frida' ), 'section' => 'brnhmbx_sectionSlider', 'settings' => 'brnhmbx_color_Sli_Box'
	) ) );
	$wp_customize->add_control( 'brnhmbx_rng_Sli_Box', array(
		'type'        => 'range',
		'section'     => 'brnhmbx_sectionSlider',
		'label'       => 'Slider Box Opacity',
		'input_attrs' => array(
			'min'   => 0,
			'max'   => 100,
			'step'  => 10
		)
	) );
	/* */

}
add_action( 'customize_register', 'frida_customizeAppearance' );
?>
